==> carbonkivy-0.0.1.dev0.tar.gz: carbonkivy-0.0.1.dev0/README.md <==
# CarbonKivy

[![PyPI version](https://img.shields.io/pypi/v/carbonkivy.svg?color=blueviolet&logo=pypi&logoColor=white)](https://pypi.org/project/kvdeveloper)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/carbonkivy.svg?color=yellow&logo=python&logoColor=ffd43b)](#Installation)
![Downloads](https://static.pepy.tech/badge/carbonkivy)
[![Code style: Black](https://img.shields.io/badge/code%20style-black-000000.svg?color=purple)](https://github.com/psf/black)

[![GitHub stars](https://img.shields.io/github/stars/CarbonKivy/CarbonKivy)](https://github.com/CarbonKivy/CarbonKivy/stargazers)
[![GitHub forks](https://img.shields.io/github/forks/CarbonKivy/CarbonKivy)](https://github.com/CarbonKivy/CarbonKivy/network)
[![GitHub repo size](https://img.shields.io/github/repo-size/CarbonKivy/CarbonKivy?color=red&logo=github&logoColor=white)](https://github.com/CarbonKivy/CarbonKivy)
[![GitHub issues](https://img.shields.io/github/issues/CarbonKivy/CarbonKivy?color=blueviolet&logo=github&logoColor=white)](https://github.com/CarbonKivy/CarbonKivy/issues)

<img src="https://raw.githubusercontent.com/CarbonKivy/CarbonKivy/master/assets/images/carbonkivy_logo256.png" height="180" align="right" padding="11"/>

CarbonKivy is a Python library that integrates IBM's [Carbon Design System](https://www.carbondesignsystem.com/) with the Kivy framework. It provides a modern, accessible, and user-friendly UI toolkit inspired by Carbon’s design principles, enabling developers to create consistent and visually appealing applications in Kivy.

## Community and Support
[![Discord](https://img.shields.io/discord/566880874789076992?style=for-the-badge&color=7289da&logo=discord&logoColor=7289da)](https://discord.gg/jxZ5xr3pUt)
[![Reddit](https://img.shields.io/static/v1?label=reddit&message=CarbonKivy&style=for-the-badge&color=orangered&logo=reddit&logoColor=orangered)](https://reddit.com/r/CarbonKivy)
[![GitHub Discussions](https://img.shields.io/static/v1?label=GitHub%20Discussions&message=ask%20questions&style=for-the-badge&color=blueviolet&logo=github&logoColor=white)](https://github.com/CarbonKivy/CarbonKivy/discussions)

[![YouTube CarbonKivy](https://img.shields.io/static/v1?label=Youtube&message=CarbonKivy&color=blue&logo=youtube&logoColor=ff0000)](https://youtube.com/@CarbonKivy)

Join the CarbonKivy community to get support, share your projects, and collaborate with other developers. Here are some ways you can connect with us:

- **Discord**: Join our [CarbonKivy Community Server](https://discord.gg/jxZ5xr3pUt).
- **Reddit - CarbonKivy**: Feel free to join our [Reddit Community](https://reddit.com/r/CarbonKivy).
- **GitHub Discussions**: Participate in discussions and ask questions in the [GitHub Discussions](https://github.com/CarbonKivy/CarbonKivy/discussions) section.
- **YouTube - CarbonKivy**: Follow us on YouTube [@CarbonKivy](https://youtube.com/@CarbonKivy) for updates and announcements.

[Documentation](#docs): Read the documentation.

If you encounter any issues or have questions, feel free to reach out to the community or submit an issue on GitHub.

## Features
- Comprehensive Carbon Design components tailored for Kivy.
- Modern and accessible UI elements.
- Customizable widgets for seamless integration.
- Consistent and adaptive design system.

## Installation
- Install CarbonKivy using pip:

    ```bash
    pip install carbonkivy
    ```

- Install development version using pip `(requires git installation)`:

    ```bash
    pip install git+https://github.com/CarbonKivy/CarbonKivy.git@master
    ```

    **OR**

    ```bash
    pip install https://github.com/CarbonKivy/CarbonKivy/archive/master.zip
    ```

## Requirements
- **Python**>=3.10

- kivy>=2.0.0 `(recommended kivy>=2.3.0)`

- pillow>=10.0.0

## Contributing
We welcome contributions from the community! If you're interested in contributing to KvDeveloper or its documentation, please read our [Contributing Guidelines](https://github.com/CarbonKivy/CarbonKivy/blob/master/CONTRIBUTING.md).

You can contribute by:

- Reporting bugs or suggesting features in the [Issues](https://github.com/CarbonKivy/CarbonKivy/issues) section.
- Submitting pull requests to improve the documentation or the KvDeveloper tool.
- Helping with translations or writing new guides.

For more detailed instructions, please visit our [Contributing](https://github.com/CarbonKivy/CarbonKivy/blob/master/CONTRIBUTING.md) page.

## Acknowledgements
[Kivy](https://github.com/kivy)

## License
CarbonKivy is released under the [MIT License](https://github.com/CarbonKivy/CarbonKivy/blob/master/LICENSE). You're free to use, modify, and distribute this software as long as you adhere to the terms of the license.

## Contact
For any inquiries, please contact us at [novfensec@protonmail.com](mailto:novfensec@protonmail.com).

==> carbonkivy-0.0.2.tar.gz: carbonkivy-0.0.2/README.md <==
# CarbonKivy

[![PyPI version](https://img.shields.io/pypi/v/carbonkivy.svg?color=blueviolet&logo=pypi&logoColor=white)](https://pypi.org/project/kvdeveloper)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/carbonkivy.svg?color=yellow&logo=python&logoColor=ffd43b)](#Installation)
![Downloads](https://static.pepy.tech/badge/carbonkivy)
[![Code style: Black](https://img.shields.io/badge/code%20style-black-000000.svg?color=purple)](https://github.com/psf/black)

[![GitHub stars](https://img.shields.io/github/stars/CarbonKivy/CarbonKivy)](https://github.com/CarbonKivy/CarbonKivy/stargazers)
[![GitHub forks](https://img.shields.io/github/forks/CarbonKivy/CarbonKivy)](https://github.com/CarbonKivy/CarbonKivy/network)
[![GitHub repo size](https://img.shields.io/github/repo-size/CarbonKivy/CarbonKivy?color=red&logo=github&logoColor=white)](https://github.com/CarbonKivy/CarbonKivy)
[![GitHub issues](https://img.shields.io/github/issues/CarbonKivy/CarbonKivy?color=blueviolet&logo=github&logoColor=white)](https://github.com/CarbonKivy/CarbonKivy/issues)

<p><img src="https://raw.githubusercontent.com/CarbonKivy/CarbonKivy/master/docs/source/_static/images/carbonkivy_logo256.png" height="180" align="right" padding="11"/></p>

CarbonKivy is a Python library that integrates IBM's [Carbon Design System](https://www.carbondesignsystem.com/) with the Kivy framework. It provides a modern, accessible, and user-friendly UI toolkit inspired by Carbon’s design principles, enabling developers to create consistent and visually appealing applications in Kivy.

CarbonKivy is more than just a framework—it’s a philosophy of professional application design. With features tailored for both backend functionality and frontend aesthetics, this toolkit bridges the gap between coding and creativity. Designed with both creativity and performance in mind, CarbonKivy empowers developers to build stunning, feature-rich applications with ease. Whether you’re a seasoned developer or just starting with Kivy, this framework provides the tools and resources to bring your ideas to life

## Community and Support
[![Discord](https://img.shields.io/discord/566880874789076992?style=for-the-badge&color=7289da&logo=discord&logoColor=7289da)](https://discord.gg/jxZ5xr3pUt)
[![Reddit](https://img.shields.io/static/v1?label=reddit&message=CarbonKivy&style=for-the-badge&color=orangered&logo=reddit&logoColor=orangered)](https://reddit.com/r/CarbonKivy)
[![GitHub Discussions](https://img.shields.io/static/v1?label=GitHub%20Discussions&message=ask%20questions&style=for-the-badge&color=blueviolet&logo=github&logoColor=white)](https://github.com/CarbonKivy/CarbonKivy/discussions)

[![YouTube CarbonKivy](https://img.shields.io/static/v1?label=Youtube&message=CarbonKivy&color=blue&logo=youtube&logoColor=ff0000)](https://youtube.com/@CarbonKivy)

Join the CarbonKivy community to get support, share your projects, and collaborate with other developers. Here are some ways you can connect with us:

- **Discord**: Join our [CarbonKivy Community Server](https://discord.gg/jxZ5xr3pUt).
- **Reddit - CarbonKivy**: Feel free to join our [Reddit Community](https://reddit.com/r/CarbonKivy).
- **GitHub Discussions**: Participate in discussions and ask questions in the [GitHub Discussions](https://github.com/CarbonKivy/CarbonKivy/discussions) section.
- **YouTube - CarbonKivy**: Follow us on YouTube [@CarbonKivy](https://youtube.com/@CarbonKivy) for updates and announcements.

[Documentation](https://carbonkivy.readthedocs.io): Read the documentation.

If you encounter any issues or have questions, feel free to reach out to the community or submit an issue on GitHub.

## Features
- Comprehensive Carbon Design components tailored for Kivy.
- Modern and accessible UI elements.
- Customizable widgets for seamless integration.
- Consistent and adaptive design system.

## Installation
- Install CarbonKivy using pip:

    ```bash
    pip install carbonkivy
    ```

- Install development version using pip `(requires git installation)`:

    ```bash
    pip install git+https://github.com/CarbonKivy/CarbonKivy.git@master
    ```

    **OR**

    ```bash
    pip install https://github.com/CarbonKivy/CarbonKivy/archive/master.zip
    ```

## Requirements
- **Python**>=3.10

- kivy>=2.0.0 `(recommended kivy>=2.3.0)`

- pillow>=10.0.0

## Contributing
We welcome contributions from the community! If you're interested in contributing to CarbonKivy or its documentation, please read our [Contributing Guidelines](https://github.com/CarbonKivy/CarbonKivy/blob/master/CONTRIBUTING.md).

You can contribute by:

- Reporting bugs or suggesting features in the [Issues](https://github.com/CarbonKivy/CarbonKivy/issues) section.
- Submitting pull requests to improve the documentation or the package.
- Helping with translations or writing new guides.

For more detailed instructions, please visit our [Contributing](https://github.com/CarbonKivy/CarbonKivy/blob/master/CONTRIBUTING.md) page.

## Acknowledgements
[Kivy](https://github.com/kivy)

[KivyMD](https://github.com/kivymd) - **`Inspiration of this project`**

## License
CarbonKivy is released under the [MIT License](https://github.com/CarbonKivy/CarbonKivy/blob/master/LICENSE). You're free to use, modify, and distribute this software as long as you adhere to the terms of the license.

## Contact
For any inquiries, please contact us at [novfensec@protonmail.com](mailto:novfensec@protonmail.com).
